#
# spec file for package python3-xdis
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/


Name:           python3-xdis
Version:        3.2.4
Release:        1.6
License:        GPL-2.0
Summary:        Python cross-version byte-code disassembler and marshal routines
Url:            https://github.com/rocky/python-xdis/
Group:          Development/Languages/Python
Source:         https://files.pythonhosted.org/packages/source/x/xdis/xdis-%{version}.tar.gz
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-nose >= 1.0
BuildRequires:  python3-pytest
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
Requires(post): update-alternatives
Requires(postun): update-alternatives

%description
The Python `dis` module allows you to disassemble bytecode from the same
version of Python that you are running on. But what about bytecode from
different versions?

That's what this package is for. It can marshal load Python bytecodes
from different versions of Python. The command-line routine
*pydisasm* will show disassembly output using Python 3.5 disassembly conventions

It accepts bytecodes from Python version 2.2 to 3.6 or so. The code
requires Python 2.5 or later and has been tested on Python running
versions 2.6, 2.7, pypy-5.0.1, 3.2, 3.3, 3.4, 3.5 and 3.6.

%prep
%setup -q -n xdis-%{version}

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

# Prepare for update-alternatives usage
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
mv %{buildroot}%{_bindir}/pydisasm %{buildroot}%{_bindir}/pydisasm-%{py3_ver}
ln -s -f %{_sysconfdir}/alternatives/pydisasm %{buildroot}%{_bindir}/pydisasm

%post
%_sbindir/update-alternatives \
   --install %{_bindir}/pydisasm pydisasm %{_bindir}/pydisasm-%{py3_ver} 30

%postun
if [ $1 -eq 0 ] ; then
    %_sbindir/update-alternatives --remove pydisasm %{_bindir}/pydisasm-%{py3_ver}
fi

%check
export LANG=en_US.UTF-8
python3 setup.py test

%files
%defattr(-,root,root,-)
%doc ChangeLog COPYING.txt LICENSE.gpl2 LICENSE.mit README.rst
%{_bindir}/pydisasm
%{_bindir}/pydisasm-%{py3_ver}
%ghost %{_sysconfdir}/alternatives/pydisasm
%{python3_sitelib}/*

%changelog
* Sun Jan  8 2017 arun@gmx.de
- specfile:
  * update copyright year
- update to version 3.2.4:
  * add magic for 3.6rc
  * Fix Python 3.6 disaseembly of CALL_FUNCTION_EX
  * Make magic string values unique
  * Note we can now handle Python 2.4 and 2.5
* Sat Nov 12 2016 arun@gmx.de
- update to version 3.2.3:
  * Correct Python 3.0 bytecodes
  * Go over other opcodes and add stack manipulation entries.  For
    example, for LIST_APPEND.
* Sat Nov  5 2016 arun@gmx.de
- specfile:
  * removed patch add-gpl2-license.patch, included upstream
- update to version 3.2.2:
  * Distrbute COPYING.txt
  * Correct pypy 3.2 bytecode
  * Start adding stack use on opcodes for Python 3.x
  * add stack use for Python 2 and Python3 opcodes (incomplete)
- changes from version 3.2.1:
  * Tag pypy 2.6 and 2.7 LOOKUP_METHOD properly (bug introduced in
    3.2.0. Thanks to alexwlchan of the hypothesis team.)
  * Clarification of EXTENDED_ARG in 3.0 and 3.1
  * disassemble output size indicates bytes explicitly
* Sun Oct 30 2016 arun@gmx.de
- specfile:
  * removed most of the patch, since it has been included upstream
    now the patch only adds a COPYING.txt file
- update to version 3.2.0:
  * Python 3.1 EXTENDED_ARG opcode bug fix
  * Python 3.0 opcode fixes
  * DRY opcode files
  * start noting stack-modification attributes on opcodes and use for
    Python 2.4-2.7
  * Remove hasAgumentExtended. It's not used.
  * Update Python 3.6 opcodes
  * Add magic number for Python 3.6.0b2
  * On disassembly Python 3.6 no longer knows what's up in
    CALL_FUNCTION
  * Add Python 2.1 and 3.1 bytecode tests
  * Add list2bytecode() and write_bytecode_file() - First steps in
    handling bytecode assembly
  * Change licence to GPL 2.0
* Thu Oct 20 2016 toddrme2178@gmail.com
- Update to version 3.1.0
  - expose findlabels, and findlinestarts,
  - add offset2line routine to give line number for a given offset
  - clean up requirements.txt and setup.py
- Update to version 3.0.2
  - Fix Python 1.5 disassembly bugs
  - Add Python 1.3 and 1.4 magics
- Update to version 3.0.1
  - botched classification of FOR_LOOP in Python 1.5
- Update to version 3.0.0
  - load_module returns source-code size now.
    This is incompatible with previous (2.x) versions
  - add parameter in load_module to omit parsing code,
    just other info (source-code-size, timestamp, magic, etc)
  - Disassemble 1.5 bytecodes and test
  - fix some Python 1.5 and 2.0 bytecode bugs
- Update to version 2.3.2
  - Start adding Python 1.5 and 2.0, and 2.1 opcodes
  - Disassemble dropbox 2.5
  - correct pydisasm name in --help
- Correct license is GPL-2.0.  This will be fully documented in
  next release.
- Add add-gpl2-license.patch to fix license.  This can be removed
  in the next release.
- Fix url and source url.
* Fri Sep 23 2016 toddrme2178@gmail.com
- Initial version
